Hi all,

vncviewer completely ignores -LowColorLevel switch. Proposed patch is
attached, should be fixed in both 1.0 and trunk.

Reference: https://bugzilla.redhat.com/show_bug.cgi?id=510185

Regards, Adam

-- 
Adam Tkac, Red Hat, Inc.
Index: unix/vncviewer/vncviewer.cxx
===================================================================
--- unix/vncviewer/vncviewer.cxx        (revision 3888)
+++ unix/vncviewer/vncviewer.cxx        (working copy)
@@ -1,4 +1,6 @@
 /* Copyright (C) 2002-2005 RealVNC Ltd.  All Rights Reserved.
+ * Copyright (C) 2009 TigerVNC Team
+ * Copyright (C) 2009 Red Hat, Inc.
  * 
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -331,14 +333,21 @@
   } else
     vlog.error("Could not create .vnc directory: environment variable $HOME 
not set.");
 
-  if (!::autoSelect.hasBeenSet()) {
-    // Default to AutoSelect=0 if -PreferredEncoding or -FullColor is used
-    ::autoSelect.setParam(!::preferredEncoding.hasBeenSet() 
-                       && !::fullColour.hasBeenSet()
-                       && !::fullColourAlias.hasBeenSet());
-  }
+  /*
+   * Default to AutoSelect=0 if -PreferredEncoding, -FullColor or
+   * -LowColorLevel is set.
+   */
+  if (::preferredEncoding.hasBeenSet() || ::fullColour.hasBeenSet() ||
+      ::fullColourAlias.hasBeenSet() || ::lowColourLevel.hasBeenSet() ||
+      ::lowColourLevel.hasBeenSet() || ::lowColourLevelAlias.hasBeenSet())
+    ::autoSelect.setParam(false);
+
+  /* Disable full color if LowColorLevel is set. */
+  if (::lowColourLevel.hasBeenSet() || ::lowColourLevelAlias.hasBeenSet())
+    ::fullColour.setParam(false);
+
+  /* Default to CustomCompressLevel=1 if CompressLevel is used. */
   if (!::customCompressLevel.hasBeenSet()) {
-    // Default to CustomCompressLevel=1 if CompressLevel is used.
     ::customCompressLevel.setParam(::compressLevel.hasBeenSet());
   }
 
------------------------------------------------------------------------------
Let Crystal Reports handle the reporting - Free Crystal Reports 2008 30-Day 
trial. Simplify your report design, integration and deployment - and focus on 
what you do best, core application coding. Discover what's new with 
Crystal Reports now.  http://p.sf.net/sfu/bobj-july
_______________________________________________
Tigervnc-devel mailing list
Tigervnc-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/tigervnc-devel

Reply via email to